/*
 * Copyright 2026 WebAssembly Community Group participants
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "ir/runtime-global.h"

namespace wasm {

bool RuntimeGlobal::isSubType(const Global& global) const {
  if (global.mutable_ != (mutable_ == Mutable)) {
    return false;
  }

  return global.mutable_ ? global.type == type
                         : Type::isSubType(type, global.type);
}

} // namespace wasm
